@@ -493,8 +493,6 @@ void FlatpakBackend::addResource(FlatpakResource *resource)
     // This will update also metadata (required runtime)
     updateAppSize(installation, resource);
 
-    connect(resource, &FlatpakResource::stateChanged, this, &FlatpakBackend::updatesCountChanged);
-
     m_resources.insert(resource->uniqueId(), resource);
 }
 
@@ -610,8 +608,6 @@ bool FlatpakBackend::loadInstalledApps(FlatpakInstallation *flatpakInstallation)
         FlatpakInstalledRef *ref = FLATPAK_INSTALLED_REF(g_ptr_array_index(refs, i));
 
         const auto name = QLatin1String(flatpak_ref_get_name(FLATPAK_REF(ref)));
-        const QString fnDesktop = pathApps + name + QLatin1String(".desktop");
-
 
         g_autoptr(GError) gerror = nullptr;
         auto md = flatpak_installed_ref_load_metadata(ref, m_cancellable, &gerror);
@@ -626,6 +622,7 @@ bool FlatpakBackend::loadInstalledApps(FlatpakInstallation *flatpakInstallation)
         AppStream::Metadata metadata;
         AppStream::Metadata::MetadataError error = metadata.parseDesktopData(QString::fromUtf8((const char*) data, len), name);
         if (error != AppStream::Metadata::MetadataErrorNoError) {
+            const QString fnDesktop = pathApps + name + QLatin1String(".desktop");
             qWarning() << "Failed to parse appstream metadata: " << error << fnDesktop;
             continue;
         }
@@ -847,7 +844,8 @@ void FlatpakBackend::updateAppInstalledMetadata(FlatpakInstalledRef *installedRe
     resource->updateFromRef(FLATPAK_REF(installedRef));
     resource->setInstalledSize(flatpak_installed_ref_get_installed_size(installedRef));
     resource->setOrigin(QString::fromUtf8(flatpak_installed_ref_get_origin(installedRef)));
-    resource->setState(AbstractResource::Installed);
+    if (resource->state() < AbstractResource::Installed)
+        resource->setState(AbstractResource::Installed);
 }
 
 bool FlatpakBackend::updateAppMetadata(FlatpakInstallation* flatpakInstallation, FlatpakResource *resource)
