@@ -25,8 +25,8 @@
 #include <Transaction/AddonList.h>
 
 #include <AppStreamQt/icon.h>
-#include <AppStreamQt/image.h>
 #include <AppStreamQt/screenshot.h>
+#include <appstream/AppStreamUtils.h>
 
 #include <KFormat>
 #include <KLocalizedString>
@@ -42,7 +42,13 @@
 #include <QStringList>
 #include <QTimer>
 
-FlatpakResource::FlatpakResource(AppStream::Component *component, FlatpakInstallation* installation, FlatpakBackend *parent)
+static QString iconCachePath(const AppStream::Icon &icon)
+{
+    Q_ASSERT(icon.kind() == AppStream::Icon::KindRemote);
+    return QStringLiteral("%1/icons/%2").arg(QStandardPaths::writableLocation(QStandardPaths::CacheLocation)).arg(icon.url().fileName());
+}
+
+FlatpakResource::FlatpakResource(const AppStream::Component &component, FlatpakInstallation* installation, FlatpakBackend *parent)
     : AbstractResource(parent)
     , m_appdata(component)
     , m_downloadSize(0)
@@ -53,12 +59,11 @@ FlatpakResource::FlatpakResource(AppStream::Component *component, FlatpakInstall
     , m_type(FlatpakResource::DesktopApp)
 {
     // Start fetching remote icons during initialization
-    const auto icons = m_appdata->icons();
+    const auto icons = m_appdata.icons();
     if (!icons.isEmpty()) {
         foreach (const AppStream::Icon &icon, icons) {
             if (icon.kind() == AppStream::Icon::KindRemote) {
-                const QString fileName = QStringLiteral("%1/icons/%2").arg(QStandardPaths::writableLocation(QStandardPaths::CacheLocation))
-                                                                      .arg(icon.url().fileName());
+                const QString fileName = iconCachePath(icon);
                 if (!QFileInfo::exists(fileName)) {
                     const QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::CacheLocation));
                     // Create $HOME/.cache/discover/icons folder
@@ -83,7 +88,7 @@ FlatpakResource::FlatpakResource(AppStream::Component *component, FlatpakInstall
     }
 }
 
-AppStream::Component *FlatpakResource::appstreamComponent() const
+AppStream::Component FlatpakResource::appstreamComponent() const
 {
     return m_appdata;
 }
@@ -106,7 +111,7 @@ QString FlatpakResource::availableVersion() const
 
 QString FlatpakResource::appstreamId() const
 {
-    return m_appdata->id();
+    return m_appdata.id();
 }
 
 QString FlatpakResource::arch() const
@@ -135,15 +140,15 @@ void FlatpakResource::updateFromRef(FlatpakRef* ref)
 
 QStringList FlatpakResource::categories()
 {
-    auto cats = m_appdata->categories();
-    if (m_appdata->kind() != AppStream::Component::KindAddon)
+    auto cats = m_appdata.categories();
+    if (m_appdata.kind() != AppStream::Component::KindAddon)
         cats.append(QStringLiteral("Application"));
     return cats;
 }
 
 QString FlatpakResource::comment()
 {
-    const auto summary = m_appdata->summary();
+    const auto summary = m_appdata.summary();
     if (!summary.isEmpty()) {
         return summary;
     }
@@ -164,7 +169,7 @@ int FlatpakResource::downloadSize() const
 QVariant FlatpakResource::icon() const
 {
     QIcon ret;
-    const auto icons = m_appdata->icons();
+    const auto icons = m_appdata.icons();
 
     if (!m_bundledIcon.isNull()) {
         ret = QIcon(m_bundledIcon);
@@ -172,28 +177,27 @@ QVariant FlatpakResource::icon() const
         ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
     } else foreach(const AppStream::Icon &icon, icons) {
         QStringList stock;
-        QString url = QString::fromUtf8("%1/icons/").arg(m_iconPath);
 
         switch (icon.kind()) {
             case AppStream::Icon::KindLocal:
-            case AppStream::Icon::KindCached:
-                url += icon.url().toLocalFile();
-                if (QFileInfo::exists(url)) {
-                    ret.addFile(url);
+            case AppStream::Icon::KindCached: {
+                const QString path = m_iconPath + icon.url().path();
+                if (QFileInfo::exists(path)) {
+                    ret.addFile(path, icon.size());
                 } else {
-                    ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
+                    const QString altPath = m_iconPath + QStringLiteral("%1x%2/").arg(icon.size().width()).arg(icon.size().height()) + icon.url().path();
+                    if (QFileInfo::exists(altPath)) {
+                        ret.addFile(altPath, icon.size());
+                    }
                 }
-                break;
+            }   break;
             case AppStream::Icon::KindStock:
                 stock += icon.name();
                 break;
             case AppStream::Icon::KindRemote: {
-                const QString fileName = QStringLiteral("%1/icons/%2").arg(QStandardPaths::writableLocation(QStandardPaths::CacheLocation))
-                                                                .arg(icon.url().fileName());
+                const QString fileName = iconCachePath(icon);
                 if (QFileInfo::exists(fileName)) {
-                    ret.addFile(fileName);
-                } else {
-                    ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
+                    ret.addFile(fileName, icon.size());
                 }
                 break;
             }
@@ -231,7 +235,7 @@ bool FlatpakResource::isTechnical() const
 
 QUrl FlatpakResource::homepage()
 {
-    return m_appdata->url(AppStream::Component::UrlKindHomepage);
+    return m_appdata.url(AppStream::Component::UrlKindHomepage);
 }
 
 QString FlatpakResource::flatpakFileType() const
@@ -244,7 +248,7 @@ QString FlatpakResource::flatpakName() const
     // If the flatpak name is not known (known only for installed apps), then use
     // appstream id instead;
     if (m_flatpakName.isEmpty()) {
-        return m_appdata->id();
+        return m_appdata.id();
     }
 
     return m_flatpakName;
@@ -252,19 +256,19 @@ QString FlatpakResource::flatpakName() const
 
 QString FlatpakResource::license()
 {
-    return m_appdata->projectLicense();
+    return m_appdata.projectLicense();
 }
 
 QString FlatpakResource::longDescription()
 {
-    return m_appdata->description();
+    return m_appdata.description();
 }
 
 QString FlatpakResource::name()
 {
-    QString name = m_appdata->name();
+    QString name = m_appdata.name();
     if (name.isEmpty()) {
-        name = m_appdata->id();
+        name = m_appdata.id();
     }
 
     if (name.startsWith(QLatin1String("(Nightly) "))) {
@@ -299,34 +303,6 @@ QString FlatpakResource::runtime() const
     return m_runtime;
 }
 
-static QUrl imageOfKind(const QList<AppStream::Image> &images, AppStream::Image::Kind kind)
-{
-    QUrl ret;
-    Q_FOREACH (const AppStream::Image &i, images) {
-        if (i.kind() == kind) {
-            ret = i.url();
-            break;
-        }
-    }
-    return ret;
-}
-
-static QUrl screenshot(AppStream::Component *comp, AppStream::Image::Kind kind)
-{
-    QUrl ret;
-    Q_FOREACH (const AppStream::Screenshot &s, comp->screenshots()) {
-        ret = imageOfKind(s.images(), kind);
-        if (s.isDefault() && !ret.isEmpty())
-            break;
-    }
-    return ret;
-}
-
-QUrl FlatpakResource::screenshotUrl()
-{
-    return screenshot(m_appdata, AppStream::Image::KindSource);
-}
-
 QString FlatpakResource::section()
 {
     return QString();
@@ -368,11 +344,6 @@ AbstractResource::State FlatpakResource::state()
     return m_state;
 }
 
-QUrl FlatpakResource::thumbnailUrl()
-{
-    return screenshot(m_appdata, AppStream::Image::KindThumbnail);
-}
-
 FlatpakResource::ResourceType FlatpakResource::type() const
 {
     return m_type;
@@ -398,7 +369,7 @@ QString FlatpakResource::uniqueId() const
                                                  .arg(QLatin1String("flatpak"))
                                                  .arg(origin())
                                                  .arg(typeAsString())
-                                                 .arg(m_appdata->id())
+                                                 .arg(m_appdata.id())
                                                  .arg(branch());
 }
 
@@ -408,13 +379,13 @@ void FlatpakResource::invokeApplication() const
     g_autoptr(GError) localError = nullptr;
 
     if (!flatpak_installation_launch(m_installation,
-                                     flatpakName().toStdString().c_str(),
-                                     arch().toStdString().c_str(),
-                                     branch().toStdString().c_str(),
+                                     flatpakName().toUtf8().constData(),
+                                     arch().toUtf8().constData(),
+                                     branch().toUtf8().constData(),
                                      nullptr,
                                      cancellable,
                                      &localError)) {
-        qWarning() << "Failed to launch " << m_appdata->name() << ": " << localError->message;
+        qWarning() << "Failed to launch " << m_appdata.name() << ": " << localError->message;
     }
 }
 
@@ -430,9 +401,9 @@ void FlatpakResource::fetchScreenshots()
 {
     QList<QUrl> thumbnails, screenshots;
 
-    Q_FOREACH (const AppStream::Screenshot &s, m_appdata->screenshots()) {
-        const QUrl thumbnail = imageOfKind(s.images(), AppStream::Image::KindThumbnail);
-        const QUrl plain = imageOfKind(s.images(), AppStream::Image::KindSource);
+    Q_FOREACH (const AppStream::Screenshot &s, m_appdata.screenshots()) {
+        const QUrl thumbnail = AppStreamUtils::imageOfKind(s.images(), AppStream::Image::KindThumbnail);
+        const QUrl plain = AppStreamUtils::imageOfKind(s.images(), AppStream::Image::KindSource);
         if (plain.isEmpty())
             qWarning() << "invalid screenshot for" << name();
 
@@ -544,3 +515,8 @@ QString FlatpakResource::installationPath(FlatpakInstallation* flatpakInstallati
     g_autoptr(GFile) path = flatpak_installation_get_path(flatpakInstallation);
     return QString::fromUtf8(g_file_get_path(path));
 }
+
+QUrl FlatpakResource::url() const
+{
+    return m_resourceFile.isEmpty() ? QUrl(QStringLiteral("appstream://") + appstreamId()) : m_resourceFile;
+}
