@@ -126,7 +126,9 @@ QUrl AppPackageKitResource::homepage()
 
 bool AppPackageKitResource::isTechnical() const
 {
-    return false;
+    static QString desktop = QString::fromUtf8(qgetenv("XDG_CURRENT_DESKTOP"));
+    const auto desktops = m_appdata.compulsoryForDesktops();
+    return !desktops.isEmpty() && !desktops.contains(desktop);
 }
 
 void AppPackageKitResource::fetchScreenshots()
